==> haskell-breakpoint-0.1.2.2-69-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-breakpoint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 breakpoint
version:              0.1.2.2
visibility:           public
id:                   breakpoint-0.1.2.2-93AipXgJ0qyHsxEHgJoseQ
key:                  breakpoint-0.1.2.2-93AipXgJ0qyHsxEHgJoseQ
license:              MIT
maintainer:           aaronallen8455@gmail.com
author:               Aaron Allen
synopsis:             Set breakpoints using a GHC plugin
description:
    A plugin that allows you to set breakpoints for debugging purposes.

    See the [README](https://github.com/aaronallen8455/breakpoint#breakpoint) for details.

category:             Development
abi:                  5260b6274df0a20b1f108dafb0749d03
exposed:              True
exposed-modules:
    Debug.Breakpoint Debug.Breakpoint.GhcFacade
    Debug.Breakpoint.TimerManager

hidden-modules:       Debug.Breakpoint.Renamer Debug.Breakpoint.TypeChecker
import-dirs:          /usr/lib/ghc-9.4.8/site-local/breakpoint-0.1.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/breakpoint-0.1.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/breakpoint-0.1.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-breakpoint
hs-libraries:         HSbreakpoint-0.1.2.2-93AipXgJ0qyHsxEHgJoseQ
depends:
    ansi-terminal-1.0-LkJ9SxmfbHcAL1Z7MEt8xc base-4.17.2.1
    containers-0.6.7 deepseq-1.4.8.0 ghc-9.4.8 haskeline-0.8.2
    mtl-2.2.2 pretty-simple-4.1.2.0-2z70eQKfzMZKNEwY8jEM3v
    template-haskell-2.19.0.0 text-2.0.2 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-breakpoint/html/breakpoint.haddock
haddock-html:         /usr/share/doc/haskell-breakpoint/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-breakpoint-0.1.2.2-70-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-breakpoint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 breakpoint
version:              0.1.2.2
visibility:           public
id:                   breakpoint-0.1.2.2-AOxVXfs4eQyD0booLfFV2A
key:                  breakpoint-0.1.2.2-AOxVXfs4eQyD0booLfFV2A
license:              MIT
maintainer:           aaronallen8455@gmail.com
author:               Aaron Allen
synopsis:             Set breakpoints using a GHC plugin
description:
    A plugin that allows you to set breakpoints for debugging purposes.

    See the [README](https://github.com/aaronallen8455/breakpoint#breakpoint) for details.

category:             Development
abi:                  7b6e849379c717c0ae247d2724a8ca09
exposed:              True
exposed-modules:
    Debug.Breakpoint Debug.Breakpoint.GhcFacade
    Debug.Breakpoint.TimerManager

hidden-modules:       Debug.Breakpoint.Renamer Debug.Breakpoint.TypeChecker
import-dirs:          /usr/lib/ghc-9.4.8/site-local/breakpoint-0.1.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/breakpoint-0.1.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/breakpoint-0.1.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-breakpoint
hs-libraries:         HSbreakpoint-0.1.2.2-AOxVXfs4eQyD0booLfFV2A
depends:
    ansi-terminal-1.0-LkJ9SxmfbHcAL1Z7MEt8xc base-4.17.2.1
    containers-0.6.7 deepseq-1.4.8.0 ghc-9.4.8 haskeline-0.8.2
    mtl-2.2.2 pretty-simple-4.1.2.0-GfJ0R17tftdG5dnNon2E0k
    template-haskell-2.19.0.0 text-2.0.2 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-breakpoint/html/breakpoint.haddock
haddock-html:         /usr/share/doc/haskell-breakpoint/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
